..  Titling
    ##++::==~~--''``

Balladeer
+++++++++

.. toctree::
   :maxdepth: 1

   entity

.. include:: ../../README.rst

.. _GNU General Public License: http://www.gnu.org/licenses/gpl.html
.. _issue tracker: https://github.com/tundish/balladeer/issues
.. _online documentation: https://balladeer.readthedocs.io/en/latest/index.html

* :ref:`modindex`
